Ugly
====

Fucking ugly RSS
----------------

You're a nerd.

And you need Python 3.3.

Installation
------------

::

   pip3 install ugly

Usage
-----

::

   ugly init
   ugly add "https://github.com/blog.atom"
   ugly status
   ugly next
   ugly mark unread 1
